# coding: utf-8
"""
    InductivaWebAPI

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from inductiva.client import schemas  # noqa: F401


class MachineGroupTerminateReason(schemas.EnumBase, schemas.StrSchema):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    An enumeration.
    """

    class MetaOapg:
        enum_value_to_name = {
            "user_request": "USER_REQUEST",
            "ttl_exceeded": "TTL_EXCEEDED",
            "idle_timeout": "IDLE_TIMEOUT",
            "credits_exhausted": "CREDITS_EXHAUSTED",
        }

    @schemas.classproperty
    def USER_REQUEST(cls):
        return cls("user_request")

    @schemas.classproperty
    def TTL_EXCEEDED(cls):
        return cls("ttl_exceeded")

    @schemas.classproperty
    def IDLE_TIMEOUT(cls):
        return cls("idle_timeout")

    @schemas.classproperty
    def CREDITS_EXHAUSTED(cls):
        return cls("credits_exhausted")
