# coding: utf-8
"""
    InductivaWebAPI

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from inductiva.client import schemas  # noqa: F401


class UserCostsDetails(schemas.DictSchema):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    class MetaOapg:
        required = {
            "costs",
            "expired",
            "tier_id",
            "email",
        }

        class properties:
            email = schemas.StrSchema
            tier_id = schemas.StrSchema
            expired = schemas.BoolSchema

            class costs(schemas.ListSchema):

                class MetaOapg:

                    @staticmethod
                    def items() -> typing.Type['CostDetail']:
                        return CostDetail

                def __new__(
                    cls,
                    _arg: typing.Union[typing.Tuple['CostDetail'],
                                       typing.List['CostDetail']],
                    _configuration: typing.Optional[
                        schemas.Configuration] = None,
                ) -> 'costs':
                    return super().__new__(
                        cls,
                        _arg,
                        _configuration=_configuration,
                    )

                def __getitem__(self, i: int) -> 'CostDetail':
                    return super().__getitem__(i)

            class name(
                    schemas.ComposedSchema,):

                class MetaOapg:
                    any_of_0 = schemas.StrSchema
                    any_of_1 = schemas.NoneSchema

                    @classmethod
                    @functools.lru_cache()
                    def any_of(cls):
                        # we need this here to make our import statements work
                        # we must store _composed_schemas in here so the code is only run
                        # when we invoke this method. If we kept this at the class
                        # level we would get an error because the class level
                        # code would be run when this module is imported, and these composed
                        # classes don't exist yet because their module has not finished
                        # loading
                        return [
                            cls.any_of_0,
                            cls.any_of_1,
                        ]

                def __new__(
                    cls,
                    *_args: typing.Union[
                        dict,
                        frozendict.frozendict,
                        str,
                        date,
                        datetime,
                        uuid.UUID,
                        int,
                        float,
                        decimal.Decimal,
                        bool,
                        None,
                        list,
                        tuple,
                        bytes,
                        io.FileIO,
                        io.BufferedReader,
                    ],
                    _configuration: typing.Optional[
                        schemas.Configuration] = None,
                    **kwargs: typing.Union[schemas.AnyTypeSchema, dict,
                                           frozendict.frozendict, str, date,
                                           datetime, uuid.UUID, int, float,
                                           decimal.Decimal, None, list, tuple,
                                           bytes],
                ) -> 'name':
                    return super().__new__(
                        cls,
                        *_args,
                        _configuration=_configuration,
                        **kwargs,
                    )

            __annotations__ = {
                "email": email,
                "tier_id": tier_id,
                "expired": expired,
                "costs": costs,
                "name": name,
            }

    costs: MetaOapg.properties.costs
    expired: MetaOapg.properties.expired
    tier_id: MetaOapg.properties.tier_id
    email: MetaOapg.properties.email

    @typing.overload
    def __getitem__(
            self, name: typing_extensions.Literal["email"]
    ) -> MetaOapg.properties.email:
        ...

    @typing.overload
    def __getitem__(
        self, name: typing_extensions.Literal["tier_id"]
    ) -> MetaOapg.properties.tier_id:
        ...

    @typing.overload
    def __getitem__(
        self, name: typing_extensions.Literal["expired"]
    ) -> MetaOapg.properties.expired:
        ...

    @typing.overload
    def __getitem__(
            self, name: typing_extensions.Literal["costs"]
    ) -> MetaOapg.properties.costs:
        ...

    @typing.overload
    def __getitem__(
            self, name: typing_extensions.Literal["name"]
    ) -> MetaOapg.properties.name:
        ...

    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema:
        ...

    def __getitem__(self, name: typing.Union[typing_extensions.Literal[
        "email",
        "tier_id",
        "expired",
        "costs",
        "name",
    ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)

    @typing.overload
    def get_item_oapg(
            self, name: typing_extensions.Literal["email"]
    ) -> MetaOapg.properties.email:
        ...

    @typing.overload
    def get_item_oapg(
        self, name: typing_extensions.Literal["tier_id"]
    ) -> MetaOapg.properties.tier_id:
        ...

    @typing.overload
    def get_item_oapg(
        self, name: typing_extensions.Literal["expired"]
    ) -> MetaOapg.properties.expired:
        ...

    @typing.overload
    def get_item_oapg(
            self, name: typing_extensions.Literal["costs"]
    ) -> MetaOapg.properties.costs:
        ...

    @typing.overload
    def get_item_oapg(
        self, name: typing_extensions.Literal["name"]
    ) -> typing.Union[MetaOapg.properties.name, schemas.Unset]:
        ...

    @typing.overload
    def get_item_oapg(
            self, name: str
    ) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]:
        ...

    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal[
        "email",
        "tier_id",
        "expired",
        "costs",
        "name",
    ], str]):
        return super().get_item_oapg(name)

    def __new__(
        cls,
        *_args: typing.Union[
            dict,
            frozendict.frozendict,
        ],
        costs: typing.Union[
            MetaOapg.properties.costs,
            list,
            tuple,
        ],
        expired: typing.Union[
            MetaOapg.properties.expired,
            bool,
        ],
        tier_id: typing.Union[
            MetaOapg.properties.tier_id,
            str,
        ],
        email: typing.Union[
            MetaOapg.properties.email,
            str,
        ],
        name: typing.Union[MetaOapg.properties.name, dict,
                           frozendict.frozendict, str, date, datetime,
                           uuid.UUID, int, float, decimal.Decimal, bool, None,
                           list, tuple, bytes, io.FileIO, io.BufferedReader,
                           schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict,
                               frozendict.frozendict, str, date, datetime,
                               uuid.UUID, int, float, decimal.Decimal, None,
                               list, tuple, bytes],
    ) -> 'UserCostsDetails':
        return super().__new__(
            cls,
            *_args,
            costs=costs,
            expired=expired,
            tier_id=tier_id,
            email=email,
            name=name,
            _configuration=_configuration,
            **kwargs,
        )


from inductiva.client.model.cost_detail import CostDetail
