# coding: utf-8
"""
    InductivaWebAPI

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Generated by: https://openapi-generator.tech
"""

from inductiva.client.paths.compute_group.delete import DeleteVmGroup
from inductiva.client.paths.compute_group_status.get import GetGroupStatus
from inductiva.client.paths.compute_price.get import GetInstancePrice
from inductiva.client.paths.compute_group_name.get import GetVmGroupByName
from inductiva.client.paths.compute_groups.get import ListActiveUserInstanceGroups
from inductiva.client.paths.compute_machine_types.get import ListAvailableMachineTypes
from inductiva.client.paths.compute_groups_history.get import ListUserInstanceGroups
from inductiva.client.paths.compute_group.post import RegisterVmGroup
from inductiva.client.paths.compute_group_start.post import StartVmGroup


class ComputeApi(
        DeleteVmGroup,
        GetGroupStatus,
        GetInstancePrice,
        GetVmGroupByName,
        ListActiveUserInstanceGroups,
        ListAvailableMachineTypes,
        ListUserInstanceGroups,
        RegisterVmGroup,
        StartVmGroup,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass
