# coding: utf-8
"""
    InductivaWebAPI

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Generated by: https://openapi-generator.tech
"""

from inductiva.client.paths.users_organization_costs.get import GetOrganizationCosts
from inductiva.client.paths.users_capabilities.get import GetUserCapabilities
from inductiva.client.paths.users_costs.get import GetUserCosts
from inductiva.client.paths.users_info.get import GetUserInfo
from inductiva.client.paths.users_quotas.get import GetUserQuotas


class UsersApi(
        GetOrganizationCosts,
        GetUserCapabilities,
        GetUserCosts,
        GetUserInfo,
        GetUserQuotas,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass
